@@ -1,5 +1,5 @@
 package VM::EC2::Security::CredentialCache;
-$VM::EC2::Security::CredentialCache::VERSION = '0.18';
+$VM::EC2::Security::CredentialCache::VERSION = '0.20';
 use strict;
 use warnings;
 use DateTime::Format::ISO8601;
@@ -30,19 +30,20 @@ my $credentials;
 my $credential_expiration_dt;
 
 sub get {
+    my $now = shift;
     if (!defined($credentials)) {
         my $meta = VM::EC2::Instance::Metadata->new;
         defined($meta) || die("Unable to retrieve instance metadata");
         $credentials= $meta->iam_credentials;
         defined($credentials) || die("No IAM credentials retrieved from instance metadata");
-        $credential_expiration_dt = DateTime::Format::ISO8601->parse_datetime($credentials->expiration());
-
+        $credential_expiration_dt = DateTime::Format::ISO8601->parse_datetime($credentials->expiration())->epoch();
         return $credentials;
     }
 
     # AWS provides new credentials atleast 5 minutes before the expiration of the old 
     # credentials, but we'll only start looking at 4 minutes
-    if ($credential_expiration_dt->subtract_datetime_absolute(DateTime->now())->in_units('minutes') > 4) {
+    $now //= time;
+    if ($credential_expiration_dt - $now > 240) {
         return $credentials;
     } 
         
